@@ -9,16 +9,16 @@ use crate::{
     types::AddDependencyResult
 };
 
-#[async_trait(?Send)]
+#[async_trait]
 pub trait InterfaceDependencySetStrategy {
-    async fn set_transient_interface<TInterface: ?Sized + 'static, TType: Constructor + Unsize<TInterface>>(&self) -> AddDependencyResult<()>;
+    async fn set_transient_interface<TInterface: Sync + Send + ?Sized + 'static, TType: Constructor + Unsize<TInterface>>(&self) -> AddDependencyResult<()>;
     async fn set_singleton_interface<TInterface: Sync + Send + ?Sized + 'static, TType: Constructor + Unsize<TInterface>>(&self) -> AddDependencyResult<()>;
     async fn set_scoped_interface<TInterface: Sync + Send + ?Sized + 'static, TType: Constructor + Unsize<TInterface>>(&self) -> AddDependencyResult<()>;
 }
 
-#[async_trait(?Send)]
+#[async_trait]
 impl InterfaceDependencySetStrategy for DependencyContext {
-    async fn set_transient_interface<TInterface: ?Sized + 'static, TType: Constructor + Unsize<TInterface>>(&self) -> AddDependencyResult<()> {
+    async fn set_transient_interface<TInterface: Sync + Send + ?Sized + 'static, TType: Constructor + Unsize<TInterface>>(&self) -> AddDependencyResult<()> {
         self.add_transient::<Box<TInterface>>(Box::new(InterfaceConstructor::new::<TInterface, TType>())).await
     }
 
