@@ -4,8 +4,10 @@ pub (crate) mod single_transient_closure;
 pub (crate) mod single_singleton;
 pub (crate) mod single_singleton_interface;
 pub (crate) mod single_singleton_closure;
+pub (crate) mod singleton_instance;
 pub (crate) mod single_scoped;
 pub (crate) mod single_scoped_interface;
+pub (crate) mod scoped_instance;
 pub (crate) mod remove_scoped_dependency;
 pub (crate) mod nested_dependency_singleton;
 pub (crate) mod nested_dependency_scoped;
