@@ -14,7 +14,7 @@ struct TransientDependency1 {
     pub str: String,
 }
 
-#[async_trait(?Send)]
+#[async_trait]
 impl Constructor for TransientDependency1 {
     async fn ctor(_: crate::DependencyContext) ->  BuildDependencyResult<Self> {
         Ok(Self { str: "test".to_string() })
@@ -28,7 +28,7 @@ struct TransientDependency2 {
     pub d2: Arc<RwLock<TransientDependency1>>,
 }
 
-#[async_trait(?Send)]
+#[async_trait]
 impl Constructor for TransientDependency2 {
     async fn ctor(ctx: crate::DependencyContext) -> BuildDependencyResult<Self> {
         Ok(Self {
