@@ -13,7 +13,7 @@ struct SingletonDependency1 {
     pub str: String,
 }
 
-#[async_trait(?Send)]
+#[async_trait]
 impl Constructor for SingletonDependency1 {
     async fn ctor(_: crate::DependencyContext) ->  BuildDependencyResult<Self> {
         Ok(Self { str: "test".to_string() })
@@ -26,7 +26,7 @@ struct SingletonDependency2 {
     pub d2: Arc<RwLock<SingletonDependency1>>,
 }
 
-#[async_trait(?Send)]
+#[async_trait]
 impl Constructor for SingletonDependency2 {
     async fn ctor(ctx: crate::DependencyContext) -> BuildDependencyResult<Self> {
         Ok(Self {
