@@ -11,7 +11,7 @@ struct TransientDependency1 {
     pub d2: TransientDependency2,
 }
 
-#[async_trait(?Send)]
+#[async_trait]
 impl Constructor for TransientDependency1 {
     async fn ctor(ctx: crate::DependencyContext) -> BuildDependencyResult<Self> {
         Ok(Self {
@@ -26,7 +26,7 @@ struct TransientDependency2 {
     pub str: String,
 }
 
-#[async_trait(?Send)]
+#[async_trait]
 impl Constructor for TransientDependency2 {
     async fn ctor(_: crate::DependencyContext) ->  BuildDependencyResult<Self> {
         Ok(Self { str: "test".to_string() })
